@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import os
 import stat
 import re
@@ -39,15 +40,16 @@ from calculate.lib.utils.common import cmpVersion
 from calculate.desktop._cl_keys import getKey, clearKey
 from calculate.lib.convertenv import convertEnv
 from calculate.lib.encrypt import encrypt
-from client_cache import userCache
+from .client_cache import userCache
 from shutil import copy2
 from socket import gethostbyname
 import tarfile
 from calculate.desktop.desktop import Desktop
-from calculate.client.rsync import ProfileSyncer, ProfileSyncerError
+from .rsync import ProfileSyncer, ProfileSyncerError
 from calculate.lib.utils.common import get_fastlogin_domain_path
 
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
+from functools import reduce
 
 _ = lambda x: x
 setLocalTranslate('cl_client3', sys.modules[__name__])
@@ -203,7 +205,7 @@ class commandServer(color_print):
         except ldap.INVALID_CREDENTIALS:
             errMessage = _("Wrong password")
             return False, errMessage
-        except ldap.LDAPError, e:
+        except ldap.LDAPError as e:
             errMessage = e[0]['desc']
             return False, errMessage
         return True, errMessage
@@ -218,10 +220,10 @@ class commandServer(color_print):
                     стандартного ввода (stdin)
         pwDialog  - структура для вывода приглашения в режиме диалога
         """
-        if optStdIn and options.has_key(optStdIn):
+        if optStdIn and optStdIn in options:
             pwdA = sys.stdin.readline().rstrip()
             pwdB = sys.stdin.readline().rstrip()
-        elif optDialog and options.has_key(optDialog):
+        elif optDialog and optDialog in options:
             if not pwDialog:
                 pwDialog = [_("New password"),
                             _("Retype the new password")]
@@ -361,17 +363,13 @@ class Client(commandServer, encrypt, Desktop):
         deletePaths = self.clVars.Get("cl_sync_del_path")
         if not deletePaths:
             deletePaths = []
-        excludePaths = " ".join(map(
-            lambda x: '--exclude="/%s"' % x.replace('"', "").replace(
-                "'", ""),
-            skipPaths + deletePaths + list(skipList)))
+        excludePaths = " ".join(('--exclude="/%s"' % x.replace('"', "").replace("'", "") for x 
+            in skipPaths + deletePaths + list(skipList)))
         if sync == "login":
             if os.path.exists(userHome) and \
                     os.path.exists(remoteProfile):
-                filterPath = " ".join(map(
-                    lambda x: '--filter="P /%s"' % x.replace(
-                        '"', "").replace("'", ""),
-                    skipPaths))
+                filterPath = " ".join(('--filter="P /%s"' % x.replace(
+                        '"', "").replace("'", "") for x in skipPaths))
                 execStr = ('/usr/bin/rsync --delete-excluded --delete %s %s '
                            '-rlptgo -x -v -v -v  %s/ %s/'
                            % (excludePaths, filterPath,
@@ -429,7 +427,7 @@ class Client(commandServer, encrypt, Desktop):
                 try:
                     if iniParser(configFileName).setVar(
                             'rsync', {'files': rsync.getFilesNum()}):
-                        os.chmod(configFileName, 0600)
+                        os.chmod(configFileName, 0o600)
                         os.chown(configFileName, uid, gid)
                 except Exception:
                     pass
@@ -437,7 +435,7 @@ class Client(commandServer, encrypt, Desktop):
             try:
                 if iniParser(configFileName).setVar(
                         'rsync', {'exitcode': rsync.getExitCode()}):
-                    os.chmod(configFileName, 0600)
+                    os.chmod(configFileName, 0o600)
                     os.chown(configFileName, uid, gid)
             except Exception:
                 pass
@@ -452,8 +450,8 @@ class Client(commandServer, encrypt, Desktop):
             # get directory permissions
             mode = getModeFile(changeDir, mode="mode")
             # if permission wrong( not 0700) then change it
-            if mode != 0700:
-                os.chmod(changeDir, 0700)
+            if mode != 0o700:
+                os.chmod(changeDir, 0o700)
         return True
 
     def clearHomeDir(self, homeDir):
@@ -671,7 +669,7 @@ class Client(commandServer, encrypt, Desktop):
             self.createUserDirectory(pathConfig, uid, gid)
         try:
             if iniParser(configFileName).setVar(nameSection, varsDict):
-                os.chmod(configFileName, 0600)
+                os.chmod(configFileName, 0o600)
                 os.chown(configFileName, uid, gid)
         except Exception:
             return False
@@ -688,7 +686,7 @@ class Client(commandServer, encrypt, Desktop):
                     self.createUserDirectory(pdir, uid, gid)
                 os.mkdir(userdir)
                 os.chown(userdir, uid, gid)
-                os.chmod(userdir, 0700)
+                os.chmod(userdir, 0o700)
             except OSError:
                 raise ClientError(_("Failed to create the directory") + ". " +
                                   _("Permission denied: '%s'") % userdir)
@@ -784,11 +782,15 @@ class Client(commandServer, encrypt, Desktop):
                 filesDir.append(fd)
         # find files in Desktop
         pathDesktop = path.join(userHome, desktopDir)
-        filesDirDesk = filter(lambda x: (not path.islink(x) and
-                                         not path.split(x)[1].startswith(
-                                             '.') and
-                                         not x.rpartition('.')[2] == 'desktop'),
-                              listDirectory(pathDesktop, fullPath=True))
+        # filesDirDesk = filter(lambda x: (not path.islink(x) and
+        #                                  not path.split(x)[1].startswith(
+        #                                      '.') and
+        #                                  not x.rpartition('.')[2] == 'desktop'),
+        #                       listDirectory(pathDesktop, fullPath=True))
+        filesDirDesk = [x for x in listDirectory(pathDesktop, fullPath=True) 
+            if (not path.islink(x) and
+                not path.split(x)[1].startswith('.') and
+                not x.rpartition('.')[2] == 'desktop')]
         filesDir += filesDirDesk
         if not filesDir or not path.exists(resourcePath):
             # remove empty Moved folder
@@ -836,12 +838,8 @@ class Client(commandServer, encrypt, Desktop):
         for privateHomeDir in self.privateDirs:
             privateDir = os.path.join(userHome, privateHomeDir)
             if os.path.isdir(privateDir):
-                # .ssh files relative user home directory
-                privateFiles += map(lambda x: os.path.join(privateHomeDir, x),
-                                    filter(lambda x: \
-                                               os.path.isfile(
-                                                   os.path.join(privateDir, x)),
-                                           os.listdir(privateDir)))
+                privateFiles += [os.path.join(privateHomeDir, x) for x in os.listdir(privateDir) 
+                    if os.path.isfile(os.path.join(privateDir, x))]
         return self.privateFiles + privateFiles
 
     def removePrivateFiles(self, userHome):
@@ -888,8 +886,7 @@ class Client(commandServer, encrypt, Desktop):
         Generation file list in user home directory, exclude mount dirs
         """
         lHomeDir = len(homeDir) + 1
-        return map(lambda x: x[lHomeDir:],
-                   find(homeDir, onefilesystem=True))
+        return [x[lHomeDir:] for x in find(homeDir, onefilesystem=True)]
 
     def removeFilesInProfile(self, homeDir, pathListFile):
         """
@@ -943,19 +940,19 @@ class Client(commandServer, encrypt, Desktop):
 
         if not os.access('/proc', os.R_OK):
             return []
-        return map(getCmd,
-                   filter(lambda x: x.isdigit(),
-                          os.listdir('/proc')))
+        return [getCmd(x) for x in os.listdir('/proc') if x.isdigit()]
 
     def clearUserKey(self, userName):
         """
         Clear user key from kernel
         """
         # find user key in kernel and check on relogout
-        if getKey(userName) and not \
-                filter(lambda x: "xdm/xdm\x00--login" in x[0] and
-                                ("USER=%s" % userName) in x[1],
-                       self.getRunCommandsWithEnv()):
+        # if getKey(userName) and not \
+        #         filter(lambda x: "xdm/xdm\x00--login" in x[0] and
+        #                         ("USER=%s" % userName) in x[1],
+        #                self.getRunCommandsWithEnv()):
+        if getKey(userName) and not any([x for x in  self.getRunCommandsWithEnv() 
+                if "xdm/xdm\x00--login" in x[0] and ("USER=%s" % userName) in x[1]]):
             # clean
             ret = clearKey(userName)
             if ret == 0:
@@ -1018,14 +1015,19 @@ class Client(commandServer, encrypt, Desktop):
         p = process(rcUpdateCmd, "show")
         if p.success():
             # получить список названии служб default уровня
-            return map(lambda x: x[0].strip(),
-                       # [\s*<название_службы>\s*,\s*default\s*]
-                       filter(lambda x: len(x) > 1 and "default" in x[1],
-                              # [\s*<название_службы>\s*,\s*уровень запуска\s*]
-                              map(lambda x: x.split('|'),
-                                  # \s*<название_службы>\s*|
-                                  # \s*<уроверь запуска>?\s*
-                                  p.readlines())))
+            # [\s*<название_службы>\s*,\s*default\s*]
+            # [\s*<название_службы>\s*,\s*уровень запуска\s*]
+            # \s*<название_службы>\s*|
+            # \s*<уроверь запуска>?\s*
+            # return map(lambda x: x[0].strip(),
+            #            # [\s*<название_службы>\s*,\s*default\s*]
+            #            filter(lambda x: len(x) > 1 and "default" in x[1],
+            #                   # [\s*<название_службы>\s*,\s*уровень запуска\s*]
+            #                   map(lambda x: x.split('|'),
+            #                       # \s*<название_службы>\s*|
+            #                       # \s*<уроверь запуска>?\s*
+            #                       p.readlines())))
+            return [x[0].strip() for x in [z.split('|') for z in p.readlines()] if len(x) > 1 and "default" in x[1]]
         else:
             raise ClientError(_("ERROR") + _(": ") + p.read())
 
@@ -1290,7 +1292,8 @@ class Client(commandServer, encrypt, Desktop):
                       "samba_nt_hash": self.getHashPasswd(password, "nt"),
                       "samba_nt_hash_old": self.getHashPasswd(curPassword,
                                                               "nt")}
-        if filter(lambda x: not x, varsConfig.values()):
+        # if filter(lambda x: not x, varsConfig.values()):
+        if [x for x in varsConfig.values() if not x]:
             return False
         # ~/.calculate/server.env
         fileConfig = os.path.join(homeDir, self.configFileServer)
@@ -1433,7 +1436,7 @@ class Client(commandServer, encrypt, Desktop):
             try:
                 if iniParser(configFileName).setVar(
                         'rsync', {'exitcode': rsync.getExitCode()}):
-                    os.chmod(configFileName, 0600)
+                    os.chmod(configFileName, 0o600)
                     os.chown(configFileName, uid, gid)
             except Exception:
                 pass
@@ -1445,8 +1448,8 @@ class Client(commandServer, encrypt, Desktop):
             # get directory permissions
             mode = getModeFile(changeDir, mode="mode")
             # if permission wrong( not 0700) then change it
-            if mode != 0700:
-                os.chmod(changeDir, 0700)
+            if mode != 0o700:
+                os.chmod(changeDir, 0o700)
         self.endTask()
         return True
 
