@@ -21,7 +21,7 @@ from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.utils.files import FilesError
 from calculate.desktop.desktop import DesktopError
 from calculate.lib.utils.samba import SambaError
-from calculate.client.client import ClientError
+from ..client import ClientError
 from calculate.lib.cl_template import TemplatesError
 from calculate.lib.utils.mount import isMount
 
