@@ -38,8 +38,8 @@ from socket import gethostbyname
 from calculate.lib.cl_ldap import ldapUser
 from calculate.lib.variables.user import LdapHelper
 import pwd
-from calculate.client.client import Client
-from calculate.client.rsync import ProfileSyncer, ProfileSyncerError
+from ..client import Client
+from ..rsync import ProfileSyncer, ProfileSyncerError
 
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 
@@ -244,9 +244,8 @@ class VariableUrUserPw(Variable, LdapHelper):
             ldapInit.bind_s(userDN, password)
         except ldap.INVALID_CREDENTIALS:
             raise VariableError(_("Wrong password"))
-        except ldap.LDAPError, e:
-            errMessage = e[0]['desc']
-            raise VariableError(errMessage)
+        except ldap.LDAPError as e:
+            raise VariableError(f"{e.args[0]['desc']}; {e.args[0]['info']}")
         return True
 
     def check(self, value):
@@ -293,7 +292,7 @@ class VariableClClientLogin(user.VariableUrLogin):
     def choice(self):
         loginChoice = user.VariableUrLogin.choice(self)
         if self.Get('cl_action') == 'passwd':
-            return filter(lambda x: x != "root", loginChoice)
+            return [x for x in loginChoice if x != "root"]
         else:
             return loginChoice
 
@@ -409,7 +408,7 @@ class VariableClLdapData(ldapUser, ReadonlyVariable):
         current server
         """
         searchPrevHost = self.searchPrevHost(userName, osLinuxShort)
-        if searchPrevHost and searchPrevHost[0][0][1].has_key('host'):
+        if searchPrevHost and 'host' in searchPrevHost[0][0][1]:
             prevHost = searchPrevHost[0][0][1]['host'][0]
         else:
             prevHost = None
@@ -544,7 +543,7 @@ class VariableClClientUserMountHost(FieldValue, ReadonlyVariable):
     column = 3
 
 
-class SyncHelper(object):
+class SyncHelper():
     """
     Вспомогательный объект для определения статуса синхронизации и времени
     по конфигурационным файлам
@@ -597,9 +596,8 @@ class SyncHelper(object):
                                         objConfig)
             timeLogout = data["date_logout"]
             timeConfig = data["date"]
-            dates = filter(None,
-                           [self.convertDate(timeLogout),
-                            self.convertDate(timeConfig)])
+            dates = [x for x in [self.convertDate(timeLogout),
+                            self.convertDate(timeConfig)] if x]
             if dates:
                 return dates[0]
         return ""
@@ -644,9 +642,8 @@ class SyncHelper(object):
             cpRemote.read_string(desktopEnvRemoteData)
             timeLogout = cpRemote.get("main", "date_logout", fallback=None)
             timeConfig = cpRemote.get("main", "date", fallback=None)
-            dates = filter(None,
-                           [self.convertDate(timeLogout),
-                            self.convertDate(timeConfig)])
+            dates = [x for x in [self.convertDate(timeLogout),
+                    self.convertDate(timeConfig)] if x]
             if dates:
                 return dates[0]
         return ""
@@ -724,7 +721,7 @@ class VariableClClientRsyncProfileSet(ReadonlyVariable):
     type = "bool"
     value = "off"
 
-
+#TODO ProfileSyncer likely doesn't work in py3
 class VariableClClientSyncReplicationSet(SyncHelper, ReadonlyVariable):
     """
     Нужно ли синхронизировать текущий профиль с удаленным доменом
@@ -789,11 +786,10 @@ class VariableClClientSymlinks(ReadonlyVariable):
     def get(self):
         skipFiles = (self.Get('cl_sync_del_path') +
                      self.Get('cl_sync_skip_path'))
-        reSkip = re.compile("|".join(map(lambda x: x.replace("*", ".*"),
-                                         skipFiles))).search
-        return filter(lambda x: not reSkip(x),
-                      find(self.Get('ur_home_path'), onefilesystem=True,
-                           filetype=FindFileType.SymbolicLink))
+        reSkip = re.compile("|".join((x.replace("*", ".*") for x in skipFiles))).search
+        return [x for x in find(self.Get('ur_home_path'), onefilesystem=True,
+                           filetype=FindFileType.SymbolicLink) 
+                           if not reSkip(x)]
 
 
 class VariableClClientNscdCache(Variable):
